@@ -94,8 +94,8 @@ class StringDiskIndex : public coll::ReadonlyCollection< StringDiskIndex >
 {
 protected:
 	IntDiskIndex index;
-	mutable BigMap& items;
-	mutable BigMap& tags;
+	BigMap& items;
+	BigMap& tags;
 
 	std::string itemconv(const int& item) const
 	{
